# Scicat Search

[![Build Status](https://travis-ci.org/garethcmurphy/scicat_pkg.svg?branch=master)](https://travis-ci.org/garethcmurphy/scicat_pkg)
[![Coverage Status](https://coveralls.io/repos/github/garethcmurphy/scicat_pkg/badge.svg?branch=master)](https://coveralls.io/github/garethcmurphy/scicat_pkg?branch=master)

This package queries data at scicat.esss.se.
You can search using a simple text search or by passing a python dictionary containing fields to query.
